.. _resources_index:

Resource Manager
================

libEnsemble comes with built-in resource management. This entails the detection of available resources (e.g. nodelists and core counts), and the allocation of resources to workers.

.. toctree::
   :maxdepth: 2
   :titlesonly:
   :caption: Resource Manager:

   overview
   resource_detection
   zero_resource_workers
   scheduler_module
   worker_resources
